# @push.rocks/tapbundle
tap bundled for tapbuffer

## Install
Install the package by running the following command in your terminal:

```bash
npm install @push.rocks/tapbundle --save-dev
```

This will add `@push.rocks/tapbundle` to your project's `devDependencies`.

## Usage
The `@push.rocks/tapbundle` package is a tap-compatible testing framework written in TypeScript, intended for use with tapbuffer. It includes a range of useful features enabling easy setup and execution of tests, assertion handling through `expect` and `expectAsync`, as well as auxiliary tools for delay and colored console output.

### Getting Started
First, ensure your project is set up with Typescript and supports ESM syntax. You can then import `tap`, `expect`, and `expectAsync` from `@push.rocks/tapbundle` to start defining your tests.

```typescript
import { tap, expect, expectAsync } from '@push.rocks/tapbundle';
```

Here is a simple test example:

```typescript
import { tap, expect } from '@push.rocks/tapbundle';

tap.test('should succeed on true assertion', async () => {
  return expect(true).toBeTrue();
});

tap.start();
```

### Defining Tests
You can define tests with descriptions and async functions. The `tap` instance manages test execution, supports test skipping, and managing exclusive tests with the `.only` modifier.

```typescript
const myTest = tap.test('expect true to be true', async () => {
  expect(true).toBeTrue();
});

const skippedTest = tap.skip.test('this test is skipped', async () => {
  // This will not be executed
});

tap.only.test('only this test will run', async () => {
  expect('TapBundle').toContainString('Tap');
});

tap.start();
```

### Using `expect` and `expectAsync`
The package provides `expect` and `expectAsync` for assertions:

```typescript
await expectAsync(Promise.resolve(true)).toBeResolved();
expect(5).toBeGreaterThan(2);
```

### Handling Asynchronous Operations
`tapbundle` facilitates working with async operations in tests. You can introduce delays or set timeouts:

```typescript
tap.test('async operation with delay', async (tools) => {
  await tools.delayFor(2000); // Wait for 2000 milliseconds
  expect(true).toBeTrue();
});

tap.start();
```

### Advanced Usage
#### Pre Tasks
You can define tasks to run before test execution begins:

```typescript
tap.preTask('setup database', async () => {
  // Perform setup here
});

tap.test('test database connection', async () => {
  // Test the setup
});

tap.start();
```

#### Accessing Test Metadata
Each test returns a `TapTest` instance, from which you can access metadata and manipulate test behavior:

```typescript
const test = tap.test('metadata example', async (tools) => {
  tools.allowFailure();
  expect(true).toBeTrue();
});

tap.start().then(() => {
  console.log(`Test duration: ${test.hrtMeasurement.milliSeconds}ms`);
});
```

### Running Tests
Tests are executed by calling `tap.start()`. This method runs all defined tests in sequence and respects `.skip` and `.only` modifiers.

### Debugging and Output
`@push.rocks/tapbundle` supports colored console output via `consolecolor` to help with debugging and test result readability:

```typescript
tap.test('colored output', async (tools) => {
  const coloredString = await tools.coloredString('Hello, world!', 'green');
  console.log(coloredString);
});

tap.start();
```

This detailed guide covers the most important aspects of using `@push.rocks/tapbundle` for testing in your TypeScript projects. Explore the included functions and tools to fully leverage this comprehensive testing framework.

## License and Legal Information

This repository contains open-source code that is licensed under the MIT License. A copy of the MIT License can be found in the [license](license) file within this repository. 

**Please note:** The MIT License does not grant permission to use the trade names, trademarks, service marks, or product names of the project, except as required for reasonable and customary use in describing the origin of the work and reproducing the content of the NOTICE file.

### Trademarks

This project is owned and maintained by Task Venture Capital GmbH. The names and logos associated with Task Venture Capital GmbH and any related products or services are trademarks of Task Venture Capital GmbH and are not included within the scope of the MIT license granted herein. Use of these trademarks must comply with Task Venture Capital GmbH's Trademark Guidelines, and any usage must be approved in writing by Task Venture Capital GmbH.

### Company Information

Task Venture Capital GmbH  
Registered at District court Bremen HRB 35230 HB, Germany

For any legal inquiries or if you require further information, please contact us via email at hello@task.vc.

By using this repository, you acknowledge that you have read this section, agree to comply with its terms, and understand that the licensing of the code does not imply endorsement by Task Venture Capital GmbH of any derivative works.
